@@ -49,16 +49,20 @@ getDrugRecords <- function(cdm,
   checkmate::reportAssertions(collection = errorMessage)
 
   records <- cdm[[drugRecordsTable]] %>%
-    dplyr::inner_join(cdm[[includedConceptsTable]] %>%
-      dplyr::select("concept_id","concept_name", "ingredient_concept_id", "ingredient"),
-    by = c("drug_concept_id" = "concept_id")) %>%
+    dplyr::inner_join(
+      cdm[[includedConceptsTable]] %>%
+        dplyr::select("concept_id", "concept_name", "ingredient_concept_id", "ingredient"),
+      by = c("drug_concept_id" = "concept_id")
+    ) %>%
     dplyr::filter(.data$ingredient_concept_id == .env$ingredient) %>%
     dplyr::rename("drug" = "concept_name")
 
   # store result
-  records <- computeDBQuery(table = records,
-                            tablePrefix = tablePrefix,
-                            tableName = "_DED_drug_records",
-                            cdm = cdm)
+  records <- computeDBQuery(
+    table = records,
+    tablePrefix = tablePrefix,
+    tableName = "_DED_drug_records",
+    cdm = cdm
+  )
   return(records)
 }
