@@ -9,20 +9,12 @@ knitr::opts_chunk$set(
 
 ## ----setup--------------------------------------------------------------------
 library(DrugExposureDiagnostics)
-library(dplyr)
-library(DT)
-
-# acetaminophen concept id is 1125315
-acetaminophen <- 1125315
 cdm <- mockDrugExposure()
-acetaminophen_checks <- executeChecks(
+result <- executeChecks(
   cdm = cdm,
-  ingredients = acetaminophen,
   checks = "sourceConcept"
 )
 
-## -----------------------------------------------------------------------------
-datatable(acetaminophen_checks$drugSourceConceptsOverall,
-  rownames = FALSE
-)
+## ----eval=FALSE---------------------------------------------------------------
+#  DT::datatable(result$drugSourceConceptsOverall, rownames = FALSE)
 
